import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface GoogleBigtableTableConfig extends cdktf.TerraformMetaArguments {
    /**
    * The name of the Bigtable instance.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_bigtable_table#instance_name GoogleBigtableTable#instance_name}
    */
    readonly instanceName: string;
    /**
    * The name of the table.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_bigtable_table#name GoogleBigtableTable#name}
    */
    readonly name: string;
    /**
    * The ID of the project in which the resource belongs. If it is not provided, the provider project is used.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_bigtable_table#project GoogleBigtableTable#project}
    */
    readonly project?: string;
    /**
    * A list of predefined keys to split the table on. !> Warning: Modifying the split_keys of an existing table will cause Terraform to delete/recreate the entire google_bigtable_table resource.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_bigtable_table#split_keys GoogleBigtableTable#split_keys}
    */
    readonly splitKeys?: string[];
    /**
    * column_family block
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_bigtable_table#column_family GoogleBigtableTable#column_family}
    */
    readonly columnFamily?: GoogleBigtableTableColumnFamily[] | cdktf.IResolvable;
}
export interface GoogleBigtableTableColumnFamily {
    /**
    * The name of the column family.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_bigtable_table#family GoogleBigtableTable#family}
    */
    readonly family: string;
}
export declare function googleBigtableTableColumnFamilyToTerraform(struct?: GoogleBigtableTableColumnFamily | cdktf.IResolvable): any;
/**
* Represents a {@link https://www.terraform.io/docs/providers/google-beta/r/google_bigtable_table google_bigtable_table}
*/
export declare class GoogleBigtableTable extends cdktf.TerraformResource {
    static readonly tfResourceType = "google_bigtable_table";
    /**
    * Create a new {@link https://www.terraform.io/docs/providers/google-beta/r/google_bigtable_table google_bigtable_table} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options GoogleBigtableTableConfig
    */
    constructor(scope: Construct, id: string, config: GoogleBigtableTableConfig);
    get id(): string;
    private _instanceName?;
    get instanceName(): string;
    set instanceName(value: string);
    get instanceNameInput(): string | undefined;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    private _project?;
    get project(): string;
    set project(value: string);
    resetProject(): void;
    get projectInput(): string | undefined;
    private _splitKeys?;
    get splitKeys(): string[];
    set splitKeys(value: string[]);
    resetSplitKeys(): void;
    get splitKeysInput(): string[] | undefined;
    private _columnFamily?;
    get columnFamily(): GoogleBigtableTableColumnFamily[] | cdktf.IResolvable;
    set columnFamily(value: GoogleBigtableTableColumnFamily[] | cdktf.IResolvable);
    resetColumnFamily(): void;
    get columnFamilyInput(): cdktf.IResolvable | GoogleBigtableTableColumnFamily[] | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
