import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface GoogleIamDenyPolicyConfig extends cdktf.TerraformMetaArguments {
    /**
    * The display name of the rule.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_iam_deny_policy#display_name GoogleIamDenyPolicy#display_name}
    */
    readonly displayName?: string;
    /**
    * The name of the policy.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_iam_deny_policy#name GoogleIamDenyPolicy#name}
    */
    readonly name: string;
    /**
    * The attachment point is identified by its URL-encoded full resource name.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_iam_deny_policy#parent GoogleIamDenyPolicy#parent}
    */
    readonly parent: string;
    /**
    * rules block
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_iam_deny_policy#rules GoogleIamDenyPolicy#rules}
    */
    readonly rules: GoogleIamDenyPolicyRules[] | cdktf.IResolvable;
    /**
    * timeouts block
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_iam_deny_policy#timeouts GoogleIamDenyPolicy#timeouts}
    */
    readonly timeouts?: GoogleIamDenyPolicyTimeouts;
}
export interface GoogleIamDenyPolicyRulesDenyRuleDenialCondition {
    /**
    * Description of the expression. This is a longer text which describes the expression,
  e.g. when hovered over it in a UI.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_iam_deny_policy#description GoogleIamDenyPolicy#description}
    */
    readonly description?: string;
    /**
    * Textual representation of an expression in Common Expression Language syntax.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_iam_deny_policy#expression GoogleIamDenyPolicy#expression}
    */
    readonly expression: string;
    /**
    * String indicating the location of the expression for error reporting,
  e.g. a file name and a position in the file.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_iam_deny_policy#location GoogleIamDenyPolicy#location}
    */
    readonly location?: string;
    /**
    * Title for the expression, i.e. a short string describing its purpose.
  This can be used e.g. in UIs which allow to enter the expression.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_iam_deny_policy#title GoogleIamDenyPolicy#title}
    */
    readonly title?: string;
}
export declare function googleIamDenyPolicyRulesDenyRuleDenialConditionToTerraform(struct?: GoogleIamDenyPolicyRulesDenyRuleDenialConditionOutputReference | GoogleIamDenyPolicyRulesDenyRuleDenialCondition): any;
export declare class GoogleIamDenyPolicyRulesDenyRuleDenialConditionOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleIamDenyPolicyRulesDenyRuleDenialCondition | undefined;
    set internalValue(value: GoogleIamDenyPolicyRulesDenyRuleDenialCondition | undefined);
    private _description?;
    get description(): string;
    set description(value: string);
    resetDescription(): void;
    get descriptionInput(): string | undefined;
    private _expression?;
    get expression(): string;
    set expression(value: string);
    get expressionInput(): string | undefined;
    private _location?;
    get location(): string;
    set location(value: string);
    resetLocation(): void;
    get locationInput(): string | undefined;
    private _title?;
    get title(): string;
    set title(value: string);
    resetTitle(): void;
    get titleInput(): string | undefined;
}
export interface GoogleIamDenyPolicyRulesDenyRule {
    /**
    * The permissions that are explicitly denied by this rule. Each permission uses the format '{service-fqdn}/{resource}.{verb}',
  where '{service-fqdn}' is the fully qualified domain name for the service. For example, 'iam.googleapis.com/roles.list'.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_iam_deny_policy#denied_permissions GoogleIamDenyPolicy#denied_permissions}
    */
    readonly deniedPermissions?: string[];
    /**
    * The identities that are prevented from using one or more permissions on Google Cloud resources.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_iam_deny_policy#denied_principals GoogleIamDenyPolicy#denied_principals}
    */
    readonly deniedPrincipals?: string[];
    /**
    * Specifies the permissions that this rule excludes from the set of denied permissions given by deniedPermissions.
  If a permission appears in deniedPermissions and in exceptionPermissions then it will not be denied.
  The excluded permissions can be specified using the same syntax as deniedPermissions.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_iam_deny_policy#exception_permissions GoogleIamDenyPolicy#exception_permissions}
    */
    readonly exceptionPermissions?: string[];
    /**
    * The identities that are excluded from the deny rule, even if they are listed in the deniedPrincipals.
  For example, you could add a Google group to the deniedPrincipals, then exclude specific users who belong to that group.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_iam_deny_policy#exception_principals GoogleIamDenyPolicy#exception_principals}
    */
    readonly exceptionPrincipals?: string[];
    /**
    * denial_condition block
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_iam_deny_policy#denial_condition GoogleIamDenyPolicy#denial_condition}
    */
    readonly denialCondition: GoogleIamDenyPolicyRulesDenyRuleDenialCondition;
}
export declare function googleIamDenyPolicyRulesDenyRuleToTerraform(struct?: GoogleIamDenyPolicyRulesDenyRuleOutputReference | GoogleIamDenyPolicyRulesDenyRule): any;
export declare class GoogleIamDenyPolicyRulesDenyRuleOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleIamDenyPolicyRulesDenyRule | undefined;
    set internalValue(value: GoogleIamDenyPolicyRulesDenyRule | undefined);
    private _deniedPermissions?;
    get deniedPermissions(): string[];
    set deniedPermissions(value: string[]);
    resetDeniedPermissions(): void;
    get deniedPermissionsInput(): string[] | undefined;
    private _deniedPrincipals?;
    get deniedPrincipals(): string[];
    set deniedPrincipals(value: string[]);
    resetDeniedPrincipals(): void;
    get deniedPrincipalsInput(): string[] | undefined;
    private _exceptionPermissions?;
    get exceptionPermissions(): string[];
    set exceptionPermissions(value: string[]);
    resetExceptionPermissions(): void;
    get exceptionPermissionsInput(): string[] | undefined;
    private _exceptionPrincipals?;
    get exceptionPrincipals(): string[];
    set exceptionPrincipals(value: string[]);
    resetExceptionPrincipals(): void;
    get exceptionPrincipalsInput(): string[] | undefined;
    private _denialCondition;
    get denialCondition(): GoogleIamDenyPolicyRulesDenyRuleDenialConditionOutputReference;
    putDenialCondition(value: GoogleIamDenyPolicyRulesDenyRuleDenialCondition): void;
    get denialConditionInput(): GoogleIamDenyPolicyRulesDenyRuleDenialCondition | undefined;
}
export interface GoogleIamDenyPolicyRules {
    /**
    * The description of the rule.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_iam_deny_policy#description GoogleIamDenyPolicy#description}
    */
    readonly description?: string;
    /**
    * deny_rule block
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_iam_deny_policy#deny_rule GoogleIamDenyPolicy#deny_rule}
    */
    readonly denyRule?: GoogleIamDenyPolicyRulesDenyRule;
}
export declare function googleIamDenyPolicyRulesToTerraform(struct?: GoogleIamDenyPolicyRules | cdktf.IResolvable): any;
export interface GoogleIamDenyPolicyTimeouts {
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_iam_deny_policy#create GoogleIamDenyPolicy#create}
    */
    readonly create?: string;
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_iam_deny_policy#delete GoogleIamDenyPolicy#delete}
    */
    readonly delete?: string;
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_iam_deny_policy#update GoogleIamDenyPolicy#update}
    */
    readonly update?: string;
}
export declare function googleIamDenyPolicyTimeoutsToTerraform(struct?: GoogleIamDenyPolicyTimeoutsOutputReference | GoogleIamDenyPolicyTimeouts | cdktf.IResolvable): any;
export declare class GoogleIamDenyPolicyTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleIamDenyPolicyTimeouts | undefined;
    set internalValue(value: GoogleIamDenyPolicyTimeouts | undefined);
    private _create?;
    get create(): string;
    set create(value: string);
    resetCreate(): void;
    get createInput(): string | undefined;
    private _delete?;
    get delete(): string;
    set delete(value: string);
    resetDelete(): void;
    get deleteInput(): string | undefined;
    private _update?;
    get update(): string;
    set update(value: string);
    resetUpdate(): void;
    get updateInput(): string | undefined;
}
/**
* Represents a {@link https://www.terraform.io/docs/providers/google-beta/r/google_iam_deny_policy google_iam_deny_policy}
*/
export declare class GoogleIamDenyPolicy extends cdktf.TerraformResource {
    static readonly tfResourceType = "google_iam_deny_policy";
    /**
    * Create a new {@link https://www.terraform.io/docs/providers/google-beta/r/google_iam_deny_policy google_iam_deny_policy} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options GoogleIamDenyPolicyConfig
    */
    constructor(scope: Construct, id: string, config: GoogleIamDenyPolicyConfig);
    private _displayName?;
    get displayName(): string;
    set displayName(value: string);
    resetDisplayName(): void;
    get displayNameInput(): string | undefined;
    get etag(): string;
    get id(): string;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    private _parent?;
    get parent(): string;
    set parent(value: string);
    get parentInput(): string | undefined;
    private _rules?;
    get rules(): GoogleIamDenyPolicyRules[] | cdktf.IResolvable;
    set rules(value: GoogleIamDenyPolicyRules[] | cdktf.IResolvable);
    get rulesInput(): cdktf.IResolvable | GoogleIamDenyPolicyRules[] | undefined;
    private _timeouts;
    get timeouts(): GoogleIamDenyPolicyTimeoutsOutputReference;
    putTimeouts(value: GoogleIamDenyPolicyTimeouts): void;
    resetTimeouts(): void;
    get timeoutsInput(): GoogleIamDenyPolicyTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
